@@ -22,7 +22,6 @@ __all__ = [
 	'Message',
 	'Statement',
 	'Chunks',
-	'Rows',
 	'Cursor',
 	'Connector',
 	'Category',
@@ -228,6 +227,8 @@ class Cursor(
 		0 : 'ABSOLUTE',
 		1 : 'RELATIVE',
 		2 : 'FROM_END',
+		3 : 'FORWARD',
+		4 : 'BACKWARD'
 	}
 	_direction_map = {
 		True : 'FORWARD',
@@ -293,6 +294,10 @@ class Cursor(
 		  Relative.
 		 ``2`` or ``"FROM_END"``
 		  Absolute from end.
+		 ``3`` or ``"FORWARD"``
+		  Relative forward.
+		 ``4`` or ``"BACKWARD"``
+		  Relative backward.
 
 		Direction effects whence. If direction is BACKWARD, ABSOLUTE positioning
 		will effectively be FROM_END, RELATIVE's position will be negated, and
@@ -592,8 +597,8 @@ class StoredProcedure(
 		"""
 
 ##
-# Arguably, it would be wiser to isolate blocks, prepared transactions, and
-# savepoints, but the utility of the separation is not significant. It's really
+# Arguably, it would be wiser to isolate blocks, and savepoints, but the utility
+# of the separation is not significant. It's really
 # more interesting as a formality that the user may explicitly state the
 # type of the transaction. However, this capability is not completely absent
 # from the current interface as the configuration parameters, or lack thereof,
@@ -704,10 +709,6 @@ class Transaction(Element):
 		Run the `start` method and return self.
 		"""
 
-	def __context__(self):
-		'Return self.'
-		return self
-
 	@abstractmethod
 	def __exit__(self, typ, obj, tb):
 		"""
@@ -1112,7 +1113,7 @@ class Connector(Element):
 		Create and connect. Arguments will be given to the `Connection` instance's
 		`connect` method.
 		"""
-		return self.driver.connection(self)
+		return self.driver.connection(self, *args, **kw)
 
 	def __init__(self,
 		user : "required keyword specifying the user name(str)" = None,
@@ -1198,12 +1199,6 @@ class Connection(Database):
 		`True` when `None`.
 		"""
 
-	@abstractmethod
-	def __context__(self):
-		"""
-		Returns the connection object, self.
-		"""
-
 class Driver(Element):
 	"""
 	The `Driver` element provides the `Connector` and other information
@@ -1372,9 +1367,6 @@ class Cluster(Element):
 		readied.
 		"""
 
-	def __context__(self):
-		return self
-
 	@abstractmethod
 	def __exit__(self, exc, val, tb):
 		"""
