@@ -10,7 +10,7 @@ author = 'James William Pye <x@jwp.name>'
 description = 'Driver and tools library for PostgreSQL'
 
 # Set this to the target date when approaching a release.
-date = 'Sat Sep 18 12:17:29 MST 2010'
-tags = set(('documentation','fixes','features','deprecations'))
-version_info = (1, 0, 2)
+date = 'Sat Sep 24 12:00:00 2011'
+tags = set(('bugs', 'features',))
+version_info = (1, 0, 3)
 version = '.'.join(map(str, version_info)) + (date is None and 'dev' or '')
