@@ -1,25 +1,19 @@
 ##
-# copyright 2009, James William Pye
-# http://python.projects.postgresql.org
+# .release.distutils - distutils data
 ##
 """
 Python distutils data provisions module.
 
 For sub-packagers, the `prefixed_packages` and `prefixed_extensions` functions
-should be of particular interest. It is not recommended that sub-packagers
-include the `scripts` keyword from py-postgresql in their setup() call.
-If the distribution including ``py-postgresql`` uses the standard layout,
-chances are that `prefixed_extensions` and `prefixed_packages` will supply the
-appropriate information by default as they use `default_prefix` which is derived
-from the module's `__package__`.
+should be of particular interest. If the distribution including ``py-postgresql``
+uses the standard layout, chances are that `prefixed_extensions` and
+`prefixed_packages` will supply the appropriate information by default as they
+use `default_prefix` which is derived from the module's `__package__`.
 """
 import sys
 import os
-from .. import \
-	__version__ as version, \
-	__project__ as name, \
-	__project_id__ as url
-from distutils.core import Extension
+from ..project import version, name, identity as url
+from distutils.core import Extension, Command
 
 LONG_DESCRIPTION = """
 py-postgresql is a set of Python modules providing interfaces to various parts
@@ -55,7 +49,7 @@ However, PG-API is recommended as it provides greater utility.
 
 Once installed, try out the ``pg_python`` console script::
 
-	$ pg_python -h localhost -p port -U theuser -d database_name
+	$ python3 -m postgresql.bin.pg_python -h localhost -p port -U theuser -d database_name
 
 If a successful connection is made to the remote host, it will provide a Python
 console with the database connection bound to the `db` name.
@@ -92,16 +86,16 @@ subpackages = [
 	'test',
 	'documentation',
 	'python',
+	'port',
 	'release',
 	# Modules imported from other packages.
 	'resolved',
+	'types',
+	'types.io',
 ]
 extensions_data = {
-	'protocol.optimized' : {
-		'sources' : [os.path.join('protocol', 'optimized', 'module.c')],
-	},
-	'python.optimized' : {
-		'sources' : [os.path.join('python', 'optimized.c')],
+	'port.optimized' : {
+		'sources' : [os.path.join('port', 'optimized', 'module.c')],
 	},
 }
 
@@ -110,11 +104,6 @@ subpackage_data = {
 	'documentation' : ['*.txt']
 }
 
-scripts = [
-	'postgresql/bin/pg_dotconf',
-	'postgresql/bin/pg_python',
-]
-
 try:
 	# :)
 	if __package__ is not None:
@@ -137,7 +126,8 @@ def prefixed_extensions(
 		yield Extension(
 			pkg_prefix + mod,
 			[os.path.join(path_prefix, src) for src in data['sources']],
-			libraries = data.get('libraries', ())
+			libraries = data.get('libraries', ()),
+			optional = True,
 		)
 
 def prefixed_packages(
@@ -182,8 +172,25 @@ def standard_setup_keywords(build_extensions = True, prefix = default_prefix):
 		'classifiers' : CLASSIFIERS,
 		'packages' : list(prefixed_packages(prefix = prefix)),
 		'package_data' : dict(prefixed_package_data(prefix = prefix)),
-		'scripts' : scripts,
+		'cmdclass': dict(test=TestCommand),
 	}
 	if build_extensions:
 		d['ext_modules'] = list(prefixed_extensions(prefix = prefix))
 	return d
+
+class TestCommand(Command):
+	description = "run tests"
+
+	# List of option tuples: long name, short name (None if no short
+	# name), and help string.
+	user_options = []
+
+	def initialize_options(self):
+		pass
+
+	def finalize_options(self):
+		pass
+
+	def run(self):
+		import unittest
+		unittest.main(module='postgresql.test.testall', argv=('setup.py',))
